# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

bootstrapServers: Optional[str]
"""
A list of kafka brokers
"""

caCert: Optional[str]
"""
CA certificate file to validate the server's certificate.
"""

caCertFile: Optional[str]
"""
Path to a CA certificate file to validate the server's certificate.
"""

clientCert: Optional[str]
"""
The client certificate.
"""

clientCertFile: Optional[str]
"""
Path to a file containing the client certificate.
"""

clientKey: Optional[str]
"""
The private key that the certificate was issued for.
"""

clientKeyFile: Optional[str]
"""
Path to a file containing the private key that the certificate was issued for.
"""

clientKeyPassphrase: Optional[str]
"""
The passphrase for the private key that the certificate was issued for.
"""

kafkaVersion: Optional[str]
"""
The version of Kafka protocol to use in `$MAJOR.$MINOR.$PATCH` format. Some features may not be available on older
versions. Default is 2.7.0.
"""

saslAwsAccessKey: Optional[str]
"""
The AWS access key.
"""

saslAwsCredsDebug: Optional[bool]
"""
Set this to true to turn AWS credentials debug.
"""

saslAwsProfile: Optional[str]
"""
AWS profile name to use
"""

saslAwsRegion: Optional[str]
"""
AWS region where MSK is deployed.
"""

saslAwsRoleArn: Optional[str]
"""
Arn of an AWS IAM role to assume
"""

saslAwsSecretKey: Optional[str]
"""
The AWS secret key.
"""

saslAwsToken: Optional[str]
"""
The AWS session token. Only required if you are using temporary security credentials.
"""

saslMechanism: str
"""
SASL mechanism, can be plain, scram-sha512, scram-sha256, aws-iam
"""

saslPassword: Optional[str]
"""
Password for SASL authentication.
"""

saslTokenUrl: Optional[str]
"""
The url to retrieve oauth2 tokens from, when using sasl mechanism oauthbearer
"""

saslUsername: Optional[str]
"""
Username for SASL authentication.
"""

skipTlsVerify: bool
"""
Set this to true only if the target Kafka server is an insecure development instance.
"""

timeout: Optional[int]
"""
Timeout in seconds
"""

tlsEnabled: bool
"""
Enable communication with the Kafka Cluster over TLS.
"""

